package com.futurescale.sa.controller.command.edit
{
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.DraftVO;
	import com.futurescale.sa.model.vo.NoteVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.SeasonVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.model.vo.ValueObject;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * A request to add some new item has arisen from the 
	 * View in the form of an AppEvent. Here, we will 
	 * interpret the event, add the item, then trigger
	 * selection of that item.
	 */
	public class AddItemCommand extends SimpleCommand
	{
		override public function execute( notification:INotification ):void
		{
			var event:AppEvent = AppEvent( notification.getBody() );

			// Get the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			var context:SelectionContext = SelectionContext( scProxy.getData() );
			
			var season:SeasonVO;
			var story:StoryVO;
			var part:PartVO;
			var chapter:ChapterVO;
			var scene:SceneVO;
			var draft:DraftVO;
			var note:NoteVO;
			var vo:ValueObject;

			switch ( event.type ) 
			{
				case AppEvent.ADD_EPISODE:
					break;
				
				case AppEvent.ADD_PART:
					// add part to selected story
					story = context.story;
					part = story.getNewPart();
					context.selectStory( story );
					break;
				
				case AppEvent.ADD_CHAPTER:
					if ( context.part ) 
					{
						// add chapter to selected part
						part = context.part
						chapter =  part.getNewChapter( );
						context.selectPart( part );
					} else {
						// add chapter to selected story
						story = context.story;
						chapter =  story.getNewChapter( );
						context.selectStory( story );
					}
					break;
				
				case AppEvent.ADD_SCENE:
					if ( context.chapter ) 
					{
						// add scene to selected chapter
						chapter = context.chapter;
						scene =  chapter.getNewScene( );
						context.selectChapter( chapter );
					} else {
						// add scene to selected story
						story = context.story;
						scene =  story.getNewScene( );
						context.selectStory( story );
					}
					break;
				
				case AppEvent.ADD_DRAFT:
					// add draft to selected scene
					scene = context.scene;
					draft = scene.getNewDraft();
					context.selectScene( scene );
					break;
				
				case AppEvent.ADD_NOTE:
					// add note to selected item
					note = new NoteVO(); 
					vo = context.selectedItem;
					vo.addNote( note );
					context.selectItem( vo );
					context.selectNote( note );
					break;
			}
		}
	}
}