package com.futurescale.sa.controller.command.edit
{
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.DraftVO;
	import com.futurescale.sa.model.vo.NoteVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.SeasonVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.model.vo.ValueObject;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * A request to delete an item has arisen from the 
	 * View in the form of an AppEvent. Here, we will 
	 * interpret the event, delete the item, then trigger
	 * selection of that item.
	 */
	public class DeleteItemCommand extends SimpleCommand
	{
		override public function execute( notification:INotification ):void
		{
			var event:AppEvent = AppEvent( notification.getBody() );

			// Get the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			var context:SelectionContext = SelectionContext( scProxy.getData() );
			
			var season:SeasonVO;
			var story:StoryVO;
			var part:PartVO;
			var chapter:ChapterVO;
			var scene:SceneVO;
			var draft:DraftVO;
			var note:NoteVO;
			var vo:ValueObject;
			var n:Number;

			switch ( event.type ) 
			{
				case AppEvent.DELETE_PART:
					// delete selected part from selected story
					story = context.story;
					part = context.part;
					story.deletePart( part );
					context.selectStory( story );
					break;
				
				case AppEvent.DELETE_CHAPTER:
					if ( context.part ) 
					{
						// delete selected chapter from selected part
						part = context.part;
						chapter = context.chapter;
						part.deleteChapter( chapter );
						context.selectPart( part );
					} else {
						// delete selected chapter from selected story
						story = context.story;
						chapter = context.chapter;
						story.deleteChapter( chapter );
						context.selectStory( story );
					}
					break;
				
				case AppEvent.DELETE_SCENE:
					if ( context.chapter ) 
					{
						// delete selected scene from selected chapter
						chapter = context.chapter;
						scene = context.scene;
						chapter.deleteScene( scene );
						context.selectChapter( chapter );
					} else {
						// delete selected scene from selected story
						story = context.story;
						scene = context.scene;
						story.deleteScene( scene );
						context.selectStory( story );
					}
					break;
				
				case AppEvent.DELETE_NOTE:
					// delete selected note from selected item
					vo = context.selectedItem; 
					vo.deleteNote( context.note );
					context.selectNote( null );
					context.selectItem( vo );
					break;

				case AppEvent.DELETE_EPISODE:
					// delete selected story from selected series
					break;
				
			}
		}
	}
}