package com.futurescale.sa.controller.command.shutdown
{
	import com.futurescale.sa.controller.constant.AppConstants;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	import com.futurescale.sa.view.popup.event.PopupActionEvent;
	import com.futurescale.sa.view.popup.request.PopupRequest;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	public class ExitAppCommand extends SimpleCommand
	{

		private var event:AppEvent;
		private var context:SelectionContext;
		
		override public function execute( note:INotification ):void
		{
			// Get the event from the note body, hang onto it
			event = AppEvent( note.getBody() );
			
			// Get the SelectionContext, hang onto it
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			context = SelectionContext( scProxy.getData() );
			
			// Confirm the user's intention with regard to unsaved changes
			var confirm:PopupRequest = new PopupRequest( handleConfirmPopupNotification, this );
			sendNotification( PopupRequest.EXIT_CONFIRM_POPUP, confirm );
		}

		private function handleConfirmPopupNotification( actionNote:INotification ):void
		{
			var event:PopupActionEvent = PopupActionEvent( actionNote.getBody() );
			switch ( actionNote.getName() ) 
			{
				case PopupActionEvent.SAVE:
					saveChanges();
					closeWindow();
					break;
				
				case PopupActionEvent.DISCARD:
					closeWindow();
					break;
				
				case PopupActionEvent.CANCEL:
					// don't save, don't exit
					break;
			}
		}
		
		private function saveChanges():void		
		{
			// Save the Story or Series the user was editing
			var event:AppEvent;
			if ( context.story ) {
				event = new AppEvent( AppEvent.SAVE_STORY, 
									  context.story );
			} else {
				event = new AppEvent( AppEvent.SAVE_SERIES, 
									  context.series );
			}
			sendNotification( AppConstants.APPLY_CHANGES, event );
		}

		private function closeWindow():void		
		{
			sendNotification( AppConstants.CLOSE_WINDOW );
		}
	}
}