package com.futurescale.sa.controller.command.story
{
	import com.futurescale.sa.controller.constant.AppConstants;
	import com.futurescale.sa.model.proxy.StoryProxy;
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.view.context.SelectionContext;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/**
	 * Prepare a story for editing.
	 */
	public class EditStoryCommand extends SimpleCommand
	{
		override public function execute( note:INotification ):void
		{
			// Get the story from the note body.			
			var story:StoryVO = StoryVO( note.getBody() );
			
			// Get the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			var context:SelectionContext = SelectionContext( scProxy.getData() );

			// Be sure we have the full Story
			if ( story.isStub ) {
				var storyProxy:StoryProxy = StoryProxy( facade.retrieveProxy( StoryProxy.NAME ) );
				story = storyProxy.loadStory( story );
			}
			
			// Select the farthest point in the story for editing
			context.selectStory( story );
			var part:PartVO; 
			var chapter:ChapterVO; 
			var scene:SceneVO;
			if ( story.useScenes ) 
			{
				scene = story.scenes[ story.scenes.length-1 ];
				context.selectScene( scene );
				context.selectDraft( scene.currentDraft );
			} 
			else if ( story.useChapters ) 
			{
				chapter = story.chapters[ story.chapters.length-1 ];
				scene   = chapter.scenes[ chapter.scenes.length-1 ];
				context.selectChapter( chapter );
				context.selectScene( scene );
				context.selectDraft( scene.currentDraft );
			} 
			else if ( story.useParts ) 
			{
				part    = story.parts[ story.parts.length-1 ];
				chapter = part.chapters[ part.chapters.length-1 ];
				scene   = chapter.scenes[ chapter.scenes.length-1 ];
				context.selectPart( part );
				context.selectChapter( chapter );
				context.selectScene( scene );
				context.selectDraft( scene.currentDraft );
			}				
			
			// Tell the View to edit the story. 
			sendNotification( AppConstants.SHOW_EDITOR );
		}
	}
}