package com.futurescale.sa.controller.command.story
{
	import com.futurescale.sa.controller.constant.AppConstants;
	import com.futurescale.sa.model.proxy.StoryReadingProxy;
	import com.futurescale.sa.model.request.ServiceRequest;
	import com.futurescale.sa.model.vo.StoryVO;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	// Hypothetical (Chapter 8 - Async Behavior)
	public class SearchStoryCommand extends SimpleCommand
	{
		private var term:String; // the search term
		
		override public function execute( note:INotification ):void
		{
			// Get the search term from the note type
			term = note.getType();
			
			// Get the story stub from the note body
			var storyVO:StoryVO = StoryVO( note.getBody );
			
			// Get the StoryReadingProxy
			var proxy:IProxy = facade.retrieveProxy( StoryReadingProxy.NAME );
			var readerProxy:StoryReadingProxy = StoryReadingProxy( proxy );
			
			// Create the ServiceRequest
			var request:ServiceRequest = 
				new ServiceRequest( storyVO, searchStory, this );
			
			// Load the story
			readerProxy.loadStory( request );			
		}
		
		private function searchStory( note:INotification ):void 
		{
			// Get the completed request from the note body
			var request:ServiceRequest = ServiceRequest( note.getBody() );
			
			// Handle the result
			switch ( note.getName() ) {
				
				// RESULT_OK: Search for first occurance, send note with result
				case ServiceRequest.RESULT_OK:
					var story:StoryVO = StoryVO( request.resultData );
					var firstOccurance:int = story.getText().indexOf( term );
					sendNotification( AppConstants.SEARCH_RESULT, firstOccurance );
					break;
				
				// RESULT_FAIL: Send failure message in a note to be displayed
				case ServiceRequest.RESULT_FAIL:
					var message:String = String( request.resultData );
					sendNotification( "REPORT_FAILURE", message );
					sendNotification( AppConstants.REPORT_FAILURE, message );
					break;
			}
		}
	}
}