package com.futurescale.sa.controller.constant
{
	/**
	 * Notification constants for the 'App' (View and Controller tiers)
	 * 
	 * This could simply be a list of constants, but the approach used 
	 * here is to create a private vocabulary of verbs and nouns which 
	 * are then combined to create the public constants used by the app.
	 * 
	 * This yields clear and unique protocol for notifcation names:
	 * i.e. "StoryArchitect/Apply/Selection" 
	 * or   "StoryArchitect/Manage/Series"
	 */
	public class AppConstants
	{
		// VOCABULARY COMPONENTS
		private static const NAME:String 			= "StoryArchitect";
		private static const SEP:String 			= "/";
		private static const SA:String 				= NAME + SEP;
		
		// VERBS
		private static const MANAGE:String 			= SA + "Manage"  + SEP;
		private static const ADD:String 			= SA + "Add" 	 + SEP;
		private static const EDIT:String 			= SA + "Edit" 	 + SEP;
		private static const DELETE:String 			= SA + "Delete"  + SEP;
		private static const REMOVE:String 			= SA + "Remove"  + SEP;
		private static const APPLY:String 			= SA + "Apply"   + SEP;
		private static const SHOW:String 			= SA + "Show"    + SEP;
		private static const DISCARD:String 		= SA + "Discard" + SEP;
		private static const EXIT:String 			= SA + "Exit" 	 + SEP;
		private static const CLOSE:String 			= SA + "Close"   + SEP;
		private static const MOVE:String 			= SA + "Move"    + SEP;
		
		// NOUNS		
		private static const SERIES:String 	    	= "Series";
		private static const EPISODE:String 	    = "Episode";
		private static const STORY:String 	    	= "Story";
		private static const CAST:String 	    	= "Cast";
		private static const MILIEU:String 	    	= "Milieu";
		private static const CHARACTER:String 		= "Character";
		private static const SETTING:String 		= "Setting";
		private static const NOTE:String 			= "Note";
		private static const SELECTION:String 		= "Selection";
		private static const ITEM:String 			= "Item";
		private static const EDITOR:String 			= "Editor";
		private static const CHOOSER:String 		= "Chooser";
		private static const CHANGES:String 		= "Changes";
		private static const APP:String 			= "App";
		private static const WINDOW:String 			= "Window";

		// NOTIFICATION NAMES
		public static const STARTUP:String 			= SA + "Startup";
		
		public static const APPLY_SELECTION:String 	= APPLY  + SELECTION;
		public static const APPLY_CHANGES:String 	= APPLY  + CHANGES;
		
		public static const ADD_ITEM:String 		= ADD    + ITEM;
		public static const ADD_EPISODE:String 		= ADD    + EPISODE;

		public static const DELETE_ITEM:String 		= DELETE + ITEM;
		
		public static const CLOSE_WINDOW:String 	= CLOSE  + WINDOW;
		
		public static const DISCARD_CHANGES:String 	= DISCARD+ CHANGES;
		
		public static const EXIT_APP:String 		= EXIT	 + APP;

		public static const EDIT_STORY:String 		= EDIT	 + STORY;
		public static const EDIT_SERIES:String 		= EDIT	 + SERIES;

		public static const MOVE_ITEM:String 		= MOVE   + ITEM;
		
		public static const MANAGE_SERIES:String 	= MANAGE + SERIES;
		public static const MANAGE_STORY:String 	= MANAGE + STORY;
		public static const MANAGE_CAST:String 		= MANAGE + CAST;
		public static const MANAGE_MILIEU:String 	= MANAGE + MILIEU;

		public static const REMOVE_SELECTION:String = REMOVE + SELECTION;

		public static const SHOW_EDITOR:String 		= SHOW   + EDITOR;
		public static const SHOW_CHOOSER:String 	= SHOW   + CHOOSER;
		
	}
}