package com.futurescale.sa.view.context
{
	import com.futurescale.sa.model.vo.CastVO;
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.CharacterVO;
	import com.futurescale.sa.model.vo.DraftVO;
	import com.futurescale.sa.model.vo.MilieuVO;
	import com.futurescale.sa.model.vo.NoteVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.SeasonVO;
	import com.futurescale.sa.model.vo.SeriesVO;
	import com.futurescale.sa.model.vo.SettingVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	/**
	 * The currently selected items in the UI. 
	 * 
	 * When calling the select methods, items 
	 * below the selection in the Series/Story 
	 * hierarchy as well as the selected Note,
	 * Cast and Milieu are automatically nulled
	 * as appropriate.
	 */
	[Bindable] public class SelectionContext
	{
		public static const NAME:String = "SelectionContext";
		
		public function selectSeries( series:SeriesVO ):void
		{
			this.series  = null;
			this.series  = series;
			selectSeason( null );
			selectCast( series ? series.cast : null );
			selectMilieu( series ? series.milieu : null );
			selectItem( series );
		}
		
		public function selectSeason( season:SeasonVO ):void
		{
			this.season  = null;
			this.season  = season;
			selectStory( null );
			selectItem( season );
		}
		
		public function selectStory( story:StoryVO ):void
		{
			this.story 	 = null;
			this.story   = story;
			selectPart( null );
			selectCast( story ? story.cast : null );
			selectMilieu( story ? story.milieu : null );
			selectItem( story );
			selectedText = ( story )? story.getText(true) : "";
		}
		
		public function selectPart( part:PartVO ):void
		{
			this.part 	 = null;
			this.part    = part;
			selectChapter( null );
			selectItem( part );
			selectedText = ( part )? part.getText(true) : "";
		}
		
		public function selectChapter( chapter:ChapterVO ):void
		{
			this.chapter = null;
			this.chapter = chapter;
			selectScene( null );
			selectItem( chapter );
			selectedText = ( chapter )? chapter.getText(true) : "";
		}
		
		public function selectScene( scene:SceneVO ):void
		{
			this.scene 	 = null;
			this.scene   = scene;
			// auto-select current draft if it exists
			if ( scene && scene.currentDraft ) { 
				selectDraft( scene.currentDraft ); 
			} else {
				selectDraft( null );
			}
			selectItem( scene );
		}
		
		public function selectDraft( draft:DraftVO ):void
		{
			this.draft   = null;
			this.draft   = draft;
			if (draft) scene.currentDraft = draft;
			selectedText = ( draft )? draft.text : "";
			selectItem( scene );
		}
		
		public function selectCast( cast:CastVO ):void
		{
			this.cast = null;
			this.cast = cast;
			selectCharacter( null );
			selectItem( cast );
		}
		
		public function selectCharacter( character:CharacterVO ):void
		{
			this.character = null;
			this.character = character;
			selectItem( character );
		}
		
		public function selectMilieu( milieu:MilieuVO ):void
		{
			this.milieu = null;
			this.milieu = milieu;
			selectSetting( null );
			selectItem( milieu );
		}
		
		public function selectSetting( setting:SettingVO ):void
		{
			this.setting = null;
			this.setting = setting;
			selectItem( setting );
		}
		
		public function selectItem( item:ValueObject ):void
		{
			this.selectedItem = null;
			this.selectedItem = item;
			selectNote( null );
		}
		
		public function selectNote( note:NoteVO ):void
		{
			this.note = null;
			this.note = note;
		}
		
		// Get a description of the current selection
		// e.g., "Part 1, Chapter 5, Scene 8, Draft 1"
		public function getDescription( vo:ValueObject ):String
		{
			var desc:String = "";
			
			if ( vo is PartVO ) {
				desc = part.name;
			} 
			else if ( vo is ChapterVO ) 
			{
				desc  = ( part ) ? part.name + ", " : "";
				desc += chapter.name;
			} 
			else if ( vo is SceneVO ) 
			{
				desc   = ( part ) ? part.name + ", " : "";
				desc  += ( chapter ) ? chapter.name + ", " : "";
				desc  += scene.name;
				desc  += (scene.currentDraft) ? ", " + scene.currentDraft.name : "";
				
			} 
			else if ( vo is StoryVO ) 
			{
				desc  = ( season ) ? season.name + ", " : "";
				desc  += ( story.isEpisode ) ? story.name : "";
			} 
			else if ( vo is SeasonVO ) 
			{
				desc  = season.name;
			}
			return desc;			
		}
		
		public var selectedText:String;
		public var selectedItem:ValueObject;
		
		public var series:SeriesVO;
		public var season:SeasonVO;
		public var story:StoryVO;
		public var part:PartVO;
		public var chapter:ChapterVO;
		public var scene:SceneVO;
		public var draft:DraftVO;
		public var note:NoteVO;
		public var cast:CastVO;
		public var milieu:MilieuVO;
		public var character:CharacterVO;
		public var setting:SettingVO;
	}
}