package com.futurescale.sa.view.mediator
{
	import com.futurescale.sa.controller.constant.AppConstants;
	import com.futurescale.sa.model.proxy.SeriesProxy;
	import com.futurescale.sa.model.proxy.StoryProxy;
	import com.futurescale.sa.view.component.chooser.Chooser;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.patterns.mediator.Mediator;

	public class ChooserMediator extends Mediator
	{
		/**
		 * Mediator registration name.
		 */ 
		public static const NAME:String = "ChooserMediator";
		
		/**
		 * Construct with an instance of the StoryChooser component.
		 */
		public function ChooserMediator( chooser:Chooser )
		{
			super( NAME, chooser );
		}
		
		/**
		 * Called when mediator is registered. 
		 */
		override public function onRegister():void
		{
			// Form collaborations with required proxies
			storyProxy = StoryProxy( facade.retrieveProxy( StoryProxy.NAME ) ); 
			seriesProxy = SeriesProxy( facade.retrieveProxy( SeriesProxy.NAME ) ); 
			
			// Set required data
			chooser.storyList  = storyProxy.index;
			chooser.seriesList = seriesProxy.index;

			// Set component event listeners
			chooser.addEventListener( AppEvent.ADD_EPISODE,	  handleAppEvent );
			chooser.addEventListener( AppEvent.ADD_STORY,	  handleAppEvent );
			chooser.addEventListener( AppEvent.ADD_SERIES,	  handleAppEvent );
			chooser.addEventListener( AppEvent.EDIT_STORY,	  handleAppEvent );
			chooser.addEventListener( AppEvent.EDIT_SERIES,	  handleAppEvent );
			chooser.addEventListener( AppEvent.MANAGE_STORY,  handleAppEvent );
			chooser.addEventListener( AppEvent.MANAGE_SERIES, handleAppEvent );
		}
		
		/**
		 * Handle AppEvents from the view component.
		 */
		private function handleAppEvent( event:AppEvent ):void 
		{
			switch ( event.type ) 
			{
				case AppEvent.ADD_STORY:
					sendNotification( AppConstants.MANAGE_STORY );
					break;
				
				case AppEvent.ADD_SERIES:
					sendNotification( AppConstants.MANAGE_SERIES );
					break;
				
				case AppEvent.EDIT_STORY:
					sendNotification( AppConstants.EDIT_STORY, event.data );
					break;
				
				case AppEvent.EDIT_SERIES:
					sendNotification( AppConstants.EDIT_SERIES, event.data );
					break;
				
				case AppEvent.MANAGE_STORY:
					sendNotification( AppConstants.MANAGE_STORY, event.data );
					break;
				
				case AppEvent.MANAGE_SERIES:
					sendNotification( AppConstants.MANAGE_SERIES, event.data );
					break;
			}
		}
	
		/**
		 * Cast the view component to the correct type
		 */
		private function get chooser():Chooser
		{
			return viewComponent as Chooser;
		}
		
		private var storyProxy:StoryProxy;
		private var seriesProxy:SeriesProxy;
	}
}