package com.futurescale.sa.model.proxy
{
	import com.futurescale.sa.model.vo.CastVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	import org.puremvc.as3.patterns.proxy.Proxy;
	
	/**
	 * The CastProxy provides persistence,
	 * indexing, and caching of CastVOs
	 */
	public class CastProxy extends AbstractProxy
	{
		// Registered name
		public  static const NAME:String        = "CastProxy";

		// Filesystem folder name for storage
		private static const FOLDER:String      = "cast";
		
		// Notes sent from this Proxy
		public static const CAST_CREATED:String = NAME+"/"+FOLDER+"/created";
		public static const CAST_SAVED:String   = NAME+"/"+FOLDER+"/saved";
		public static const CAST_DELETED:String = NAME+"/"+FOLDER+"/deleted";

		/**
		 * Constructor.
		 */
		public function CastProxy( )
		{
			super( NAME );
		}
		
		/**
		 * Called by the framework when the Proxy is registered.
		 */
		override public function onRegister():void
		{
			connectToFolder( FOLDER );
		}
		
		/**
		 * Create, save, cache, and return a new Cast.
		 * 
		 * A new Cast is only created when a new Story or Series
		 * is saved. It is created, saved, and cached with a 
		 * transient Proxy instance, so that it doesn't have 
		 * to be loaded again later to be used. 
		 */
		public function createCast( name:String ):CastVO
		{
			// Create and name the Cast
			var cast:CastVO = new CastVO();
			cast.name = name;
			
			// Cache the Cast
			facade.registerProxy( new Proxy( cast.uid, cast ) );
			
			// Save the Cast and update index
			writeVO( cast );
 
			// Notify observers
			sendNotification( CAST_CREATED, cast );
			
			// Return the stub to caller
			return new CastVO( cast.getStub() );
		}

		/**
		 * Save a Milieu.
		 */
		public function saveCast( cast:CastVO ):void
		{
			// Save the Cast and update index
			writeVO( cast );

			// Notify observers
			sendNotification( CAST_SAVED, cast );
		}
		
		/**
		 * Delete a Cast.
		 * 
		 * Removes the transient Proxy holding the cached
		 * Cast if present, then removes the Cast from 
		 * filesystem. Index will be automatically updated.  
		 */
		public function deleteCast( cast:CastVO ):void
		{
			// Remove cached Cast
			if ( facade.hasProxy( cast.uid ) ) {
				facade.removeProxy( cast.uid );
			}
			// Delete Cast from filesystem and update index
			deleteVO( cast );
			
			// Notify observers with stub so Cast is GC'd
			sendNotification( CAST_DELETED, new CastVO( cast.getStub() ) );
		}
		
		/**
		/**
		 * VO Factory Method. Required for indexing in superclass.
		 */
		override protected function getVoInstance( xml:XML ):ValueObject
		{
			return new CastVO( xml );
		}
	}
}