package com.futurescale.sa.model.vo.test
{
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	import flexunit.framework.Assert;
	
	public class PartVOTest
	{		
		[Test]
		public function testPartVOWithoutXML():void
		{
			var vo:PartVO = new PartVO();
			if (! vo is PartVO ) 				Assert.fail("not an instance of PartVO");
			if (vo.chapters.length != 1 ) 		Assert.fail("chapters should be populated with 1 by default");
			if (vo.getText(false).length > 0 ) 	Assert.fail("getText() match failed");
		}

		[Test]
		public function testPartVOWithXML():void
		{
			var text1:String = "we came in?";
			var text2:String = "Isn't this where";
			var c1uid:String = "xxx";
			var c2uid:String = "yyy";
			var uid:String = "zzz";
			var sx1:XML = <Scene uid="123"><Draft uid="456" isCurrent="true">{text1}</Draft></Scene>;
			var sx2:XML = <Scene uid="456"><Draft uid="457" isCurrent="true">{text2}</Draft></Scene>;
			var cx1:XML = <Chapter uid={c1uid}>{sx1}</Chapter>;
			var cx2:XML = <Chapter uid={c2uid}>{sx2}</Chapter>;
			var xml:XML = <Part uid={uid}>{cx1}{cx2}</Part>
			var vo:PartVO = new PartVO(xml);
			if ( ! vo is PartVO ) 				Assert.fail("not an instance of PartVO");
			if ( vo.chapters.length != 2 ) 		Assert.fail("chapters collection length incorrect");
			if ( vo.chapters[0].uid != c1uid ) 	Assert.fail("chapter [0] uid match failed");
			if ( vo.chapters[1].uid != c2uid ) 	Assert.fail("chapter [1] uid match failed");
		}
				
		[Test]
		public function testGetText():void
		{
			var text1:String = "we came in?";
			var text2:String = "Isn't this where";
			var c1uid:String = "xxx";
			var c2uid:String = "yyy";
			var uid:String = "zzz";
			var text3:String = "Part 1" + ValueObject.DOUBLE_SPACE + 
							   "Chapter 1" + ValueObject.DOUBLE_SPACE + 
								text1 + ValueObject.DOUBLE_SPACE + ValueObject.DOUBLE_SPACE +
								"Chapter 2" + ValueObject.DOUBLE_SPACE + text2 + 
								ValueObject.DOUBLE_SPACE + ValueObject.DOUBLE_SPACE ;
			var sx1:XML = <Scene uid="123"><Draft uid="456" isCurrent="true">{text1}</Draft></Scene>;
			var sx2:XML = <Scene uid="456"><Draft uid="457" isCurrent="true">{text2}</Draft></Scene>;
			var cx1:XML = <Chapter uid={c1uid} ordinal="1">{sx1}</Chapter>;
			var cx2:XML = <Chapter uid={c2uid} ordinal="2">{sx2}</Chapter>;
			var xml:XML = <Part uid={uid} ordinal="1">{cx1}{cx2}</Part>
			var vo:PartVO = new PartVO(xml);
			if ( ! vo is PartVO ) 				Assert.fail("not an instance of PartVO");
			var gt:String = vo.getText(true);
			if ( gt != text3 )	Assert.fail("getText() match failed");
		}
		
	}
}