package com.futurescale.sa.model.vo.test
{
	import com.futurescale.sa.model.vo.NoteVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	import flexunit.framework.Assert;
	
	public class ValueObjectTest
	{		
		
		[Test]
		public function testValueObjectWithGoodXML():void
		{
			// test that good xml passed in is exposed properly
			var element:String = "test"
			var name:String = "testValueObjectWithXML"
			var desc:String = "Testing XML on constructor";
			var ord:Number  = 5;
			var uid:String  = "ZZp9A";
			var isStub:Boolean = true;
			var xml:XML = <{element} ordinal={ord} uid={uid} isStub={isStub}><name>{name}</name><description>{desc}</description></{element}>;
			var vo:ValueObject = new ValueObject("test", xml );
			if ( vo.name 		!= name ) 	Assert.fail("name match failed");
			if ( vo.description != desc ) 	Assert.fail("description match failed");
			if ( vo.ordinal 	!= ord ) 	Assert.fail("ordinal match failed");
			if ( vo.isStub  	!= isStub ) Assert.fail("isStub match failed");
			if ( vo.uid  		!= uid ) 	Assert.fail("uid match failed");
			if ( vo.xml  		!= xml ) 	Assert.fail("xml match failed");
		}
		
		[Test]
		public function testValueObjectWithoutXML():void
		{
			// test that a default is provided when no xml is passed in
			var element:String = "west";
			var ord:Number = 5;
			var vo:ValueObject = new ValueObject( element );
			vo.ordinal = ord;
			
			if ( vo.xml.localName()  != element ) 	Assert.fail("element name match failed");
			if ( !vo.name.length > 0 ) 				Assert.fail("default name not provided");
			if ( vo.name != element+" "+ord )		Assert.fail("default name incorrect");
			if ( !vo.uid.length > 0 ) 				Assert.fail("default uid not provided");
			if ( vo.isStub != false ) 				Assert.fail("default isStub value not false");
		}
		
		[Test]
		public function testValueObjectWithBadXML():void
		{
			// test that a bad xml element is replaced by a default 
			// and none of the bad data is preserved
			var element:String = "test"
			var name:String = "testValueObjectWithBadXML"
			var desc:String = "Testing XML on constructor";
			var ord:Number  = 12;
			var uid:String  = "1010111";
			var isStub:Boolean = true;
			var xml:XML = <jest ordinal={ord} uid={uid} isStub={isStub}><name>{name}</name><description>{desc}</description></jest>;
			var vo:ValueObject = new ValueObject("test", xml );
			if ( vo.xml.localName()  != element ) 	Assert.fail("element name match failed");
			if ( vo.name 		== name ) 	Assert.fail("name match failed");
			if ( vo.description == desc ) 	Assert.fail("description match failed");
			if ( vo.ordinal 	== ord ) 	Assert.fail("ordinal match failed");
			if ( vo.isStub  	== isStub ) Assert.fail("isStub match failed");
			if ( vo.uid  		== uid ) 	Assert.fail("uid match failed");
			if ( vo.xml  		== xml ) 	Assert.fail("xml match failed");
		}
		
		[Test]
		public function testSet_xml():void
		{
			// test that setting the xml property immediately exposes the properties
			var element:String = "test"
			var name:String = "testValueObjectWithXML"
			var desc:String = "Testing XML on constructor";
			var ord:Number  = 5;
			var uid:String  = "ZZp9A";
			var isStub:Boolean = true;
			var xml:XML = <{element} ordinal={ord} uid={uid} isStub={isStub}><name>{name}</name><description>{desc}</description></{element}>;
			var vo:ValueObject = new ValueObject("test");
			vo.xml = xml;
			if ( vo.name 		!= name ) 	Assert.fail("name match failed");
			if ( vo.description != desc ) 	Assert.fail("description match failed");
			if ( vo.ordinal 	!= ord ) 	Assert.fail("ordinal match failed");
			if ( vo.isStub  	!= isStub ) Assert.fail("isStub match failed");
			if ( vo.uid  		!= uid ) 	Assert.fail("uid match failed");
			if ( vo.xml  		!= xml ) 	Assert.fail("xml match failed");
			if ( vo.xml.localName() != element ) Assert.fail("element name match failed");
		}
		
		[Test]
		public function testSet_description():void
		{
			var desc:String = "Testing description accessors";
			var vo:ValueObject = new ValueObject("zest");
			vo.description = desc;
			if ( vo.description != desc ) Assert.fail("description match failed");
		}
		
		[Test]
		public function testSet_isStub():void
		{
			var isStub:Boolean = true;
			var vo:ValueObject = new ValueObject("nest");
			vo.isStub = isStub;
			if ( vo.isStub != isStub ) Assert.fail("isStub match failed");
		}
		
		[Test]
		public function testSet_name():void
		{
			var name:String = "Testing name accessors";
			var vo:ValueObject = new ValueObject("rest");
			vo.name = name;
			if ( vo.name != name ) Assert.fail("name match failed");
		}
		
		
		[Test]
		public function testSet_uid():void
		{
			var uid:String = "098876654564332";
			var vo:ValueObject = new ValueObject("pest");
			vo.uid = uid;
			if ( vo.uid != uid ) Assert.fail("uid match failed");
			
		}

		[Test]
		public function testSet_ordinal():void
		{
			var ord:Number = 13;
			var vo:ValueObject = new ValueObject("lest");
			vo.ordinal = ord;
			if ( vo.ordinal != ord ) Assert.fail("ordinal match failed");
		}
		
		[Test]
		public function testAddNote():void
		{
			var note:NoteVO = new NoteVO();
			note.url = "http://puremvc.org";
			note.text = "Code at the Speed of Thought";
			var vo:ValueObject = new ValueObject("fest");
			vo.addNote(note);
			if ( vo.notes.length != 1 )			Assert.fail("notes vector incorrect length");
			if ( vo.notes[0].url != note.url )	Assert.fail("notes url match failed");
		}
		
		[Test]
		public function testDeleteNote():void
		{
			var note:NoteVO = new NoteVO();
			note.url = "http://puremvc.org";
			note.text = "Code at the Speed of Thought";
			var vo:ValueObject = new ValueObject("fest");
			vo.addNote(note);
			if ( vo.notes.length != 1 )			Assert.fail("notes vector incorrect length after add");
			vo.deleteNote(note);
			if ( vo.notes.length > 0 )			Assert.fail("notes vector incorrect length after delete");
			
		}
		
		[Test]
		public function testOrdinalSort():void
		{
			var vo1:ValueObject = new ValueObject("test");
			vo1.ordinal = 1;
			
			var vo2:ValueObject = new ValueObject("test");
			vo2.ordinal = 2;
			
			var vo1vo2:Number = ValueObject.ordinalSort(vo1,vo2);
			var vo1vo1:Number = ValueObject.ordinalSort(vo1,vo1);
			var vo2vo1:Number = ValueObject.ordinalSort(vo2,vo1);
			
			if ( vo1vo2 != -1 ) Assert.fail("vo1 < vo2 sort failed");
			if ( vo1vo1 != 0 ) 	Assert.fail("vo1 = vo1 sort failed");
			if ( vo2vo1 != 1 ) 	Assert.fail("vo2 > vo1 sort failed");
		}
		
		[Test]
		public function testNameSort():void
		{
			var vo1:ValueObject = new ValueObject("test");
			vo1.name = "Apocalypse Now";
			
			var vo2:ValueObject = new ValueObject("test");
			vo2.name = "Zombie Apocalypse";
			
			var vo1vo2:Number = ValueObject.nameSort(vo1,vo2);
			var vo1vo1:Number = ValueObject.nameSort(vo1,vo1);
			var vo2vo1:Number = ValueObject.nameSort(vo2,vo1);
			
			if ( vo1vo2 != -1 ) Assert.fail("vo1 < vo2 sort failed");
			if ( vo1vo1 != 0 ) 	Assert.fail("vo1 = vo1 sort failed");
			if ( vo2vo1 != 1 ) 	Assert.fail("vo2 > vo1 sort failed");
		}
	}
}