package com.futurescale.sa.controller.command.edit
{
	import com.futurescale.sa.model.proxy.SeriesProxy;
	import com.futurescale.sa.model.proxy.StoryProxy;
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.DraftVO;
	import com.futurescale.sa.model.vo.NoteVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.SeasonVO;
	import com.futurescale.sa.model.vo.SeriesVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * Handle a request to select some new item, which 
	 * comes in the form of an AppEvent. Here, we will 
	 * interpret the event, selecting the item in the 
	 * SelectionContext shared by the View Components.
	 */
	public class ApplySelectionCommand extends SimpleCommand
	{
		override public function execute( note:INotification ):void
		{
			// Get the event from 
			var event:AppEvent = AppEvent( note.getBody() );
			
			// Get the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			var context:SelectionContext = SelectionContext( scProxy.getData() );

			switch ( event.type ) 
			{
				case AppEvent.SELECT_SERIES:
					context.selectSeries( getSeries( SeriesVO( event.data ) ) )
					break;
				
				case AppEvent.SELECT_SEASON:
					context.selectSeason( SeasonVO( event.data ) )
					break;
				
				case AppEvent.SELECT_STORY:
					context.selectStory( getStory( StoryVO( event.data ) ) );
					break;
				
				case AppEvent.SELECT_PART:
					context.selectPart( PartVO( event.data ) );
					break;
				
				case AppEvent.SELECT_CHAPTER:
					context.selectChapter( ChapterVO( event.data ) );
					break;
				
				case AppEvent.SELECT_SCENE:
					context.selectScene( SceneVO( event.data ) );
					break;
				
				case AppEvent.SELECT_DRAFT:
					context.selectDraft( DraftVO( event.data ) );
					break;
				
				case AppEvent.SELECT_NOTE:
					context.selectNote( NoteVO( event.data ) );
					break;
			}
		}

		/**
		 * Get the full StoryVO from a stub.
		 */
		private function getStory( stub:StoryVO ):StoryVO
		{
			var proxy:StoryProxy = StoryProxy( facade.retrieveProxy( StoryProxy.NAME ) );
			return proxy.loadStory( stub );
		}
		
		/**
		 * Get the full SeriesVO from a stub.
		 */
		private function getSeries( stub:SeriesVO ):SeriesVO
		{
			var proxy:SeriesProxy = SeriesProxy( facade.retrieveProxy( SeriesProxy.NAME ) );
			return proxy.loadSeries( stub );
		}
	}
}