package com.futurescale.sa.controller.command.edit
{
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.SeasonVO;
	import com.futurescale.sa.model.vo.SeriesVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.model.vo.ValueObject;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * A request to move an item has arisen from the 
	 * View in the form of an AppEvent. Here, we will 
	 * interpret the event, move the item, then trigger
	 * reselection of first the parent, then the item,
	 * causing the view to be redrawn properly.
	 */
	public class MoveItemCommand extends SimpleCommand
	{
		override public function execute( notification:INotification ):void
		{
			var event:AppEvent = AppEvent( notification.getBody() );

			// Get the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			var context:SelectionContext = SelectionContext( scProxy.getData() );
			
			var vo:ValueObject = context.selectedItem;
			var sibling:ValueObject;
			var siblingOrdinal:Number;
			var parent:ValueObject;

			// Determine sibling ordinal
			switch ( event.type ) 
			{
				case AppEvent.MOVE_AHEAD:
					siblingOrdinal = (vo.ordinal + 1)-1;
					break;
				
				case AppEvent.MOVE_BACK:
					siblingOrdinal = (vo.ordinal - 1)-1;
					break;				
			}

			// Get parent and sibling 
			if ( vo is PartVO ) {
				parent  = context.story;
				sibling = context.story.parts[ siblingOrdinal ]; 
			} 
			else if ( vo is ChapterVO ) 
			{
				parent  = ( context.part ) ? context.part : context.story;
				sibling = ( context.part ) ?
							context.part.chapters[ siblingOrdinal ] : 
							context.story.chapters[ siblingOrdinal ];
			} 
			else if ( vo is SceneVO ) 
			{
				parent  = ( context.chapter ) ? context.chapter: context.story;
				sibling = ( context.chapter ) ?
							context.chapter.scenes[ siblingOrdinal ] : 
							context.story.scenes[ siblingOrdinal ]; 
			} 
			else if ( vo is StoryVO ) 
			{
				parent  = ( context.season ) ? context.season: context.series;
				sibling = ( context.season ) ?
							context.season.stories[ siblingOrdinal ] : 
							context.series.stories[ siblingOrdinal ]; 
			} 
			else if ( vo is SeasonVO ) 
			{
				parent  = context.series;
				sibling = context.series.seasons[ siblingOrdinal ]; 
			}

			// Swap selected item and sibling
			switch ( event.type ) 
			{
				case AppEvent.MOVE_AHEAD:
					vo.ordinal++;
					sibling.ordinal--;
					break;
				
				case AppEvent.MOVE_BACK:
					vo.ordinal--;
					sibling.ordinal++;
					break;				
			}

			// Reselect parent, then the child
			if ( vo is PartVO ) {
				context.selectStory( parent as StoryVO );
				context.selectPart( vo as PartVO );
			} 
			else if ( vo is ChapterVO ) 
			{
				if ( context.part ) {
					context.selectPart( parent as PartVO );
					context.selectChapter( vo as ChapterVO );
				} else {
					context.selectStory( parent as StoryVO );
					context.selectChapter( vo as ChapterVO );
				}
			} 
			else if ( vo is SceneVO ) 
			{
				if ( context.chapter ) {
					context.selectChapter( parent as ChapterVO );
					context.selectScene( vo as SceneVO );
				} else {
					context.selectStory( parent as StoryVO );
					context.selectScene( vo as SceneVO );
				}
			} 
			else if ( vo is StoryVO ) 
			{
				if ( context.season ) {
					context.selectSeason( parent as SeasonVO );
					context.selectStory( vo as StoryVO );
				} else {
					context.selectSeries( parent as SeriesVO );
					context.selectStory( vo as StoryVO );
				}
			} 
			else if ( vo is SeasonVO ) 
			{
				context.selectSeries( parent as SeriesVO );
				context.selectSeason( vo as SeasonVO );
			}
		}
	}
}