package com.futurescale.sa.controller.command.edit
{
	import com.futurescale.sa.model.proxy.StoryProxy;
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SeriesVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * Handle a request to deselect some item, which 
	 * comes in the form of an AppEvent. Here, we will 
	 * interpret the event, selecting the item in the 
	 * SelectionContext shared by the View Components.
	 */
	public class RemoveSelectionCommand extends SimpleCommand
	{
		override public function execute( note:INotification ):void
		{
			// Get the event from 
			var event:AppEvent = AppEvent( note.getBody() );
			
			// Get the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			var context:SelectionContext = SelectionContext( scProxy.getData() );

			switch ( event.type ) 
			{
				case AppEvent.DESELECT_SEASON:
					context.selectSeries( SeriesVO( event.related ) );
					break;
				
				case AppEvent.DESELECT_STORY:
					if ( context.season ) {
						context.selectSeason( context.season );
					} else {
						context.selectStory( context.story );
					}
					break;
				
				case AppEvent.DESELECT_PART:
					context.selectStory( context.story );
					break;
				
				case AppEvent.DESELECT_CHAPTER:
					if  ( context.part ) {
						context.selectPart( context.part );
					} else {
						context.selectStory( context.story );
					}
					break;
				
				case AppEvent.DESELECT_SCENE:
					if  ( context.chapter ) {
						context.selectChapter( context.chapter );
					} else {
						context.selectStory( context.story );
					}
					break;
			}
		}
	}
}