package com.futurescale.sa.controller.command.series
{
	import com.futurescale.sa.model.proxy.SeriesProxy;
	import com.futurescale.sa.model.vo.SeriesVO;
	import com.futurescale.sa.view.popup.event.PopupActionEvent;
	import com.futurescale.sa.view.popup.request.PopupRequest;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * Add, change or delete a Series.
	 * 
	 * Popup the SeriesPopup, and if the Series is 
	 * added or saved, persist it. If deleted, confirm, 
	 * then delete it.
	 */
	public class ManageSeriesCommand extends SimpleCommand
	{
		private var series:SeriesVO;
		private var seriesProxy:SeriesProxy;
		
		override public function execute( note:INotification ):void
		{
			var seriesStub:SeriesVO = SeriesVO( note.getBody() ); // Null if adding
			seriesProxy = SeriesProxy( facade.retrieveProxy( SeriesProxy.NAME ) );
			if ( seriesStub	) series = seriesProxy.loadSeries( seriesStub );
			
			// Request the popup
			var request:PopupRequest = new PopupRequest( handleEditPopupNotification, this );
			request.data.series = series;
			sendNotification( PopupRequest.SERIES_POPUP, request );
		}
		
		/**
		 * Handle the popup actions.
		 */
		private function handleEditPopupNotification( actionNote:INotification ):void
		{
			var event:PopupActionEvent = PopupActionEvent( actionNote.getBody() );
			series = SeriesVO( event.data );
			switch ( actionNote.getName() ) 
			{
				case PopupActionEvent.ADD:
					seriesProxy.addSeries( series );
					break;
				
				case PopupActionEvent.SAVE:
					seriesProxy.saveSeries( series );
					break;
				
				case PopupActionEvent.DELETE:
					var confirm:PopupRequest = new PopupRequest( handleConfirmPopupNotification, this );
					sendNotification( PopupRequest.CONFIRMATION_POPUP, confirm );
					break;
				
				case PopupActionEvent.CANCEL:
					break;
			}
		}
		
		/**
		 * Handle the ConfirmationPopup actions.
		 */
		private function handleConfirmPopupNotification( actionNote:INotification ):void
		{
			var event:PopupActionEvent = PopupActionEvent( actionNote.getBody() );
			switch ( actionNote.getName() ) 
			{
				case PopupActionEvent.OK:
					seriesProxy.deleteSeries( series );
					break;
				
				case PopupActionEvent.CANCEL:
					break;
			}
		}
		
	}
}