package com.futurescale.sa.controller.command.startup
{
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.mediator.ApplicationMediator;
	import com.futurescale.sa.view.mediator.ChooserMediator;
	import com.futurescale.sa.view.mediator.EditorMediator;
	import com.futurescale.sa.view.popup.mediator.AlertPopupMediator;
	import com.futurescale.sa.view.popup.mediator.ConfirmationPopupMediator;
	import com.futurescale.sa.view.popup.mediator.ExitConfirmPopupMediator;
	import com.futurescale.sa.view.popup.mediator.SeriesPopupMediator;
	import com.futurescale.sa.view.popup.mediator.StoryPopupMediator;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	import org.puremvc.as3.patterns.proxy.Proxy;
	
	/** 
	 * Prepare the View.
	 * 
	 * Create a SelectionContext, cache it for access from Commands, 
	 * and inject it into the app for sharing with the display list.
	 * Also, mediate the initial view components and register popup 
	 * mediators.
	 */
	public class PrepareViewCommand extends SimpleCommand
	{
		override public function execute( note:INotification ):void
		{
			// Get the application from the note body
			var app:StoryArchitect = StoryArchitect( note.getBody() );
			
			// Register a convenience Proxy to hold the SelectionContext.
			//
			// The SelectionContext tracks the selected items in the View
			// and is not part of the domain model, but we can utilize
			// the framework Proxy class as a quick way to cache this data
			// entity used solely by the View and Controller tiers. 
			var selectionContext:SelectionContext = new SelectionContext();
			var scProxy:Proxy = new Proxy( SelectionContext.NAME, 
										   selectionContext ) 
			facade.registerProxy( scProxy ); 
			
			// Mediate the initial view components
			facade.registerMediator( new ApplicationMediator( app ) );
			facade.registerMediator( new EditorMediator( app.editor ) );
			facade.registerMediator( new ChooserMediator( app.chooser ) );
			
			// Register the popup mediators
			facade.registerMediator( new AlertPopupMediator() );
			facade.registerMediator( new ConfirmationPopupMediator() );
			facade.registerMediator( new ExitConfirmPopupMediator() );
			facade.registerMediator( new StoryPopupMediator() );
			facade.registerMediator( new SeriesPopupMediator() );
		}
	}
}