package com.futurescale.sa.controller.command.story
{
	import com.futurescale.sa.model.proxy.StoryProxy;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.view.popup.event.PopupActionEvent;
	import com.futurescale.sa.view.popup.request.PopupRequest;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.patterns.command.SimpleCommand;
	
	/** 
	 * Add, change or delete a Story.
	 * 
	 * Popup the StoryPopup, and if the Story is 
	 * added or saved, persist it. If deleted, confirm, 
	 * then delete it.
	 */
	public class ManageStoryCommand extends SimpleCommand
	{
		private var story:StoryVO;
		private var storyProxy:StoryProxy;
		
		override public function execute( note:INotification ):void
		{
			var storyStub:StoryVO = StoryVO( note.getBody() ); // Null if adding
			storyProxy = StoryProxy( facade.retrieveProxy( StoryProxy.NAME ) );
			if ( storyStub	) story = storyProxy.loadStory( storyStub );
			
			// Request the popup
			var request:PopupRequest = new PopupRequest( handleEditPopupNotification, this );
			request.data.story = story;
			sendNotification( PopupRequest.STORY_POPUP, request );
		}
				
		/**
		 * Handle the popup actions.
		 */
		private function handleEditPopupNotification( actionNote:INotification ):void
		{
			var event:PopupActionEvent = PopupActionEvent( actionNote.getBody() );
			story = StoryVO( event.data );
			switch ( actionNote.getName() ) 
			{
				case PopupActionEvent.ADD:
					storyProxy.addStory( story );
					break;
				
				case PopupActionEvent.SAVE:
					storyProxy.saveStory( story );
					break;
				
				case PopupActionEvent.DELETE:
					var confirm:PopupRequest = new PopupRequest( handleConfirmPopupNotification, this );
					confirm.data.promptText = "Delete Story?";
					sendNotification( PopupRequest.CONFIRMATION_POPUP, confirm );
					break;
				
				case PopupActionEvent.CANCEL:
					break;
			}
		}
		
		/**
		 * Handle the ConfirmationPopup actions.
		 */
		private function handleConfirmPopupNotification( actionNote:INotification ):void
		{
			var event:PopupActionEvent = PopupActionEvent( actionNote.getBody() );
			switch ( actionNote.getName() ) 
			{
				case PopupActionEvent.OK:
					storyProxy.deleteStory(story);
					break;
				
				case PopupActionEvent.CANCEL:
					break;
			}
		}		
	}
}