package com.futurescale.sa.view.mediator
{
	import com.futurescale.sa.controller.constant.AppConstants;
	import com.futurescale.sa.view.context.SelectionContext;
	import com.futurescale.sa.view.event.AppEvent;
	
	import flash.events.Event;
	
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.interfaces.IProxy;
	import org.puremvc.as3.patterns.mediator.Mediator;
	
	/**
	 * Mediate communications with the StoryArchitect component.
	 */
	public class ApplicationMediator extends Mediator
	{
		/**
		 * Mediator registration name.
		 */ 
		public static const NAME:String = "ApplicationMediator";
		
		/**
		 * Construct with an instance of the application.
		 */
		public function ApplicationMediator( app:StoryArchitect )
		{
			super( NAME, app );
		}

		/**
		 * Called when Mediator is registered.
		 */
		override public function onRegister():void
		{
			// Set the SelectionContext
			var scProxy:IProxy = facade.retrieveProxy( SelectionContext.NAME );
			app.context = SelectionContext( scProxy.getData() );		
			
			// Set the initial display mode
			app.setMode( StoryArchitect.MODE_CHOOSER );

			// Listen for attempts to close the app while editing
			app.addEventListener( AppEvent.EXIT_APP,  handleExitApp );
			
		}
		
		private function handleExitApp( event:AppEvent ):void
		{
			sendNotification( AppConstants.EXIT_APP, event );
		}
		
		/**
		 * Notifications this Mediator is interested in.
		 */
		override public function listNotificationInterests():Array
		{
			return [ AppConstants.SHOW_EDITOR,
					 AppConstants.SHOW_CHOOSER,
					 AppConstants.CLOSE_WINDOW
				    ];			
		}		
		
		/**
		 * Handle the notifications this Mediator is interested in.
		 */
		override public function handleNotification( note:INotification ):void
		{
			switch ( note.getName() ) 
			{
				case AppConstants.SHOW_EDITOR:
					app.setMode(StoryArchitect.MODE_EDITOR);
					break;
				
				case AppConstants.SHOW_CHOOSER:
					app.setMode(StoryArchitect.MODE_CHOOSER);
					break;
				
				case AppConstants.CLOSE_WINDOW:
					// User has discarded or saved, so
					// return to the chooser (where the app 
					// will allow exit) and close the window.
					app.setMode(StoryArchitect.MODE_CHOOSER);
					app.close();
			}
		}

		/**
		 * Cast the view component to the correct type;
		 */
		private function get app():StoryArchitect
		{
			return viewComponent as StoryArchitect;
		}
	}
}