package com.futurescale.sa.view.mediator
{
	import com.futurescale.sa.controller.constant.AppConstants;
	import com.futurescale.sa.view.component.editor.Editor;
	import com.futurescale.sa.view.event.AppEvent;
	
	import org.puremvc.as3.patterns.mediator.Mediator;
	
	/**
	 * Mediate communications with the Editor component.
	 */
	public class EditorMediator extends Mediator
	{
		/**
		 * Mediator registration name.
		 */ 
		public static const NAME:String = "EditorMediator";
		
		/**
		 * Construct with an instance of the Editor component.
		 */
		public function EditorMediator( editor:Editor )
		{
			super( NAME, editor );
		}

		/**
		 * Called when mediator is registered. 
		 */
		override public function onRegister():void
		{
			// Set component event listeners
			editor.addEventListener( AppEvent.ADD_STORY,		handleAppEvent );
			editor.addEventListener( AppEvent.ADD_PART,			handleAppEvent );
			editor.addEventListener( AppEvent.ADD_CHAPTER,		handleAppEvent );
			editor.addEventListener( AppEvent.ADD_SCENE,		handleAppEvent );
			editor.addEventListener( AppEvent.ADD_DRAFT,		handleAppEvent );
			editor.addEventListener( AppEvent.ADD_NOTE,			handleAppEvent );
			editor.addEventListener( AppEvent.DELETE_PART,		handleAppEvent );
			editor.addEventListener( AppEvent.DELETE_CHAPTER,	handleAppEvent );
			editor.addEventListener( AppEvent.DELETE_SCENE,		handleAppEvent );
			editor.addEventListener( AppEvent.DELETE_NOTE,		handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_SERIES,	handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_SEASON,	handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_STORY,		handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_PART,		handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_CHAPTER,	handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_SCENE,		handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_DRAFT,		handleAppEvent );
			editor.addEventListener( AppEvent.SELECT_NOTE,		handleAppEvent );
			editor.addEventListener( AppEvent.DESELECT_SERIES,	handleAppEvent );
			editor.addEventListener( AppEvent.DESELECT_SEASON,	handleAppEvent );
			editor.addEventListener( AppEvent.DESELECT_PART,	handleAppEvent );
			editor.addEventListener( AppEvent.DESELECT_CHAPTER,	handleAppEvent );
			editor.addEventListener( AppEvent.DESELECT_SCENE,	handleAppEvent );
			editor.addEventListener( AppEvent.DISCARD_STORY,	handleAppEvent );
			editor.addEventListener( AppEvent.DISCARD_SERIES,	handleAppEvent );
			editor.addEventListener( AppEvent.SAVE_STORY,		handleAppEvent );
			editor.addEventListener( AppEvent.SAVE_SERIES,		handleAppEvent );
			editor.addEventListener( AppEvent.MOVE_AHEAD,		handleAppEvent );
			editor.addEventListener( AppEvent.MOVE_BACK,		handleAppEvent );
		}

		/**
		 * Handle AppEvents from the view component.
		 */
		private function handleAppEvent( event:AppEvent ):void 
		{
			switch ( event.type ) 
			{
				// AppEvents for adding items.
				case AppEvent.ADD_STORY:
				case AppEvent.ADD_PART:
				case AppEvent.ADD_CHAPTER:
				case AppEvent.ADD_SCENE:
				case AppEvent.ADD_DRAFT:
				case AppEvent.ADD_NOTE:
					sendNotification(  AppConstants.ADD_ITEM, event );
					break;

				// AppEvents for deleting items.
				case AppEvent.DELETE_STORY:
				case AppEvent.DELETE_PART:
				case AppEvent.DELETE_CHAPTER:
				case AppEvent.DELETE_SCENE:
				case AppEvent.DELETE_DRAFT:
				case AppEvent.DELETE_NOTE:
					sendNotification( AppConstants.DELETE_ITEM, event );
					break;
				
				// AppEvents for selecting items.
				case AppEvent.SELECT_SERIES:
				case AppEvent.SELECT_SEASON:
				case AppEvent.SELECT_STORY:
				case AppEvent.SELECT_PART:
				case AppEvent.SELECT_CHAPTER:
				case AppEvent.SELECT_SCENE:
				case AppEvent.SELECT_DRAFT:
				case AppEvent.SELECT_NOTE:
					sendNotification( AppConstants.APPLY_SELECTION, event );
					break;
				
				// AppEvents for deselecting items.
				case AppEvent.DESELECT_SERIES:
				case AppEvent.DESELECT_SEASON:
				case AppEvent.DESELECT_PART:
				case AppEvent.DESELECT_CHAPTER:
				case AppEvent.DESELECT_SCENE:
					sendNotification( AppConstants.REMOVE_SELECTION, event );
					break;
				
				// AppEvents for discarding changes.
				case AppEvent.DISCARD_STORY:
				case AppEvent.DISCARD_SERIES:
					sendNotification( AppConstants.DISCARD_CHANGES, event );
					break;
				
				// AppEvents for saving changes.
				case AppEvent.SAVE_STORY:
				case AppEvent.SAVE_SERIES:
					sendNotification( AppConstants.APPLY_CHANGES, event );
					break;

				// AppEvents for moving items.
				case AppEvent.MOVE_AHEAD:
				case AppEvent.MOVE_BACK:
					sendNotification( AppConstants.MOVE_ITEM, event );
					break;
			}
		}
		
		/**
		 * Cast the view component to the correct type;
		 */
		private function get editor():Editor
		{
			return viewComponent as Editor;
		}
		
	}
}