package com.futurescale.sa.model.proxy
{
	import com.futurescale.sa.model.vo.MilieuVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	import org.puremvc.as3.patterns.proxy.Proxy;
	
	/**
	 * The MilieuProxy provides persistence, 
	 * indexing, and caching of MilieuVOs
	 */
	public class MilieuProxy extends AbstractProxy
	{
		// Registered name
		public  static const NAME:String   		  = "MilieuProxy";

		// Filesystem folder name for storage
		private static const FOLDER:String 		  = "milieu";
		
		// Notes sent from this Proxy
		public static const MILIEU_CREATED:String = NAME+"/"+FOLDER+"/created";
		public static const MILIEU_SAVED:String   = NAME+"/"+FOLDER+"/saved";
		public static const MILIEU_DELETED:String = NAME+"/"+FOLDER+"/deleted";
		
		/**
		 * Constructor.
		 */
		public function MilieuProxy( )
		{
			super( NAME );
		}

		/**
		 * Called by the framework when the Proxy is registered.
		 */
		override public function onRegister():void
		{
			connectToFolder( FOLDER );
		}
		
		/**
		 * Create, save, cache, and return a new Milieu.
		 * 
		 * A new Milieu is only created when a new Story or Series
		 * is saved, thus it is created and returned from this
		 * method rather than being passed in. It is saved, and
		 * cached with a transient Proxy instance, so that it 
		 * doesn't have to be loaded again later to be used.
		 */
		public function createMilieu( name:String ):MilieuVO
		{
			// Create and name the Milieu
			var milieu:MilieuVO = new MilieuVO();
			milieu.name = name;
			
			// Cache the Milieu
			facade.registerProxy( new Proxy( milieu.uid, milieu ) );

			// Save the Milieu and update index
			writeVO( milieu );
			
			// Notify observers 
			sendNotification( MILIEU_CREATED, milieu );
			
			// Return the stub to caller
			return new MilieuVO( milieu.getStub() );
		}
		
		/**
		 * Save a Milieu.
		 */
		public function saveMilieu( milieu:MilieuVO ):void
		{
			// Save the Milieu and update index
			writeVO( milieu );

			// Notify observers 
			sendNotification( MILIEU_SAVED, milieu );
		}
		
		/**
		 * Delete a Milieu.
		 * 
		 * Removes the transient Proxy holding the cached
		 * Milieu if present, then removes the Milieu from 
		 * filesystem. Index will be automatically updated.  
		 */
		public function deleteMilieu( milieu:MilieuVO ):void
		{
			// Remove cached Milieu
			if ( facade.hasProxy( milieu.uid ) ) {
				facade.removeProxy( milieu.uid );
			}
			
			// Delete Milieu from filesystem and update index
			deleteVO( milieu );

			// Notify observers with stub so Milieu is GC'd
			sendNotification( MILIEU_DELETED, new MilieuVO( milieu.getStub() ) );
		}
		
		/**
		 * VO Factory Method. Required for indexing in superclass.
		 */
		override protected function getVoInstance( xml:XML ):ValueObject
		{
			return new MilieuVO( xml );
		}
	}
}