package com.futurescale.sa.model.proxy
{
	import com.futurescale.sa.model.request.ServiceRequest;
	import com.futurescale.sa.model.vo.StoryVO;
	
	import mx.rpc.AsyncToken;
	import mx.rpc.IResponder;
	import mx.rpc.events.FaultEvent;
	import mx.rpc.events.ResultEvent;
	import mx.rpc.remoting.RemoteObject;
	
	import org.puremvc.as3.patterns.observer.Notification;
	import org.puremvc.as3.patterns.proxy.Proxy;
	
	// Hypothetical (Chapter 8 - Async Behavior)
	public class StoryReadingProxy extends Proxy implements IResponder
	{
		public static const NAME:String = "StoryReadingProxy";
		private var service:RemoteObject;
		
		public function StoryReadingProxy()
		{
			super( NAME );
		}
		
		// Create the service at registration time
		override public function onRegister():void
		{
			service = new RemoteObject("StoryReadingService");
		}
		
		// Load Story from remote service 
		public function loadStory( request:ServiceRequest ):void
		{ 
			var story:StoryVO = request.requestData as StoryVO;
			var token:AsyncToken =  service.loadStory( story ); 
			token.request = request;    // hang onto the request
			token.addResponder( this ); // this proxy will respond 
		}
		
		// Handle loaded story
		public function result( data:Object ):void
		{
			var event:ResultEvent 	   = ResultEvent(data);
			var token:AsyncToken 	   = event.token;
			var request:ServiceRequest = token.request;
			request.resultData         = event.result; // the loaded story
			if ( request.hasCallback ) { 
				var note:Notification;
				note = new Notification( ServiceRequest.RESULT_OK, request );
				token.request.notifyObserver( note );
			}
		}
		
		// Handle a failed story load
		public function fault( info:Object ):void
		{ 
			var event:FaultEvent       = FaultEvent(data);
			var token:AsyncToken       = event.token;
			var request:ServiceRequest = token.request;
			request.resultData         = event.message.toString();
			if ( request.hasCallback ) { 
				var note:Notification;
				note = new Notification( ServiceRequest.RESULT_FAIL, request );
				token.request.notifyObserver( note );
			}
		}
	}
}