package com.futurescale.sa.model.vo.test
{
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	import flexunit.framework.Assert;
	
	public class ChapterVOTest
	{		
		[Test]
		public function testChapterVOWithoutXML():void
		{
			var vo:ChapterVO = new ChapterVO();
			if ( ! vo is ChapterVO ) 						Assert.fail("construction failed");
			if ( ! vo.xml is XML )  						Assert.fail("default xml not provided");
			if ( vo.xml.localName() != ChapterVO.ELEMENT )	Assert.fail("improper xml default");
		}
		
		[Test]
		public function testChapterVOWithXML():void
		{
			var text:String = "This is the text";
			var chapterUid:String = "Chapter-hj-tt-35";
			var sceneUid:String = "Scene-33-55-ss";
			var draftUid:String = "Draft-xx-ww-22"
			var xml:XML = <Chapter uid={chapterUid}><Scene uid={sceneUid}><Draft uid={draftUid} isCurrent="true">{text}</Draft></Scene></Chapter>;
			var vo:ChapterVO = new ChapterVO(xml);
			if ( ! vo is ChapterVO ) 						Assert.fail("construction failed");
			if ( ! vo.xml is XML )  						Assert.fail("default xml not provided");
			if ( vo.uid != chapterUid )  					Assert.fail("chapter uid match failed");
			if ( ! vo.scenes is Vector.<SceneVO> )			Assert.fail("scenes vector not returned");
			if ( vo.scenes.length != 1 )					Assert.fail("drafts vector incorrect length");
			if ( vo.scenes[0].uid != sceneUid )				Assert.fail("sceneUid uid match failed");
		}
		
		[Test]
		public function testGetNewScene():void
		{
			var cvo:ChapterVO 	= new ChapterVO();
			var svo:SceneVO 	= cvo.getNewScene();
			if ( ! svo is SceneVO ) 						Assert.fail("construction failed");
			if ( ! svo.xml is XML )  						Assert.fail("default xml not provided");
			if ( svo.xml.localName() != SceneVO.ELEMENT )	Assert.fail("improper xml default");
			if ( svo.ordinal != 2 ) 						Assert.fail("ordinal match failed");
			if ( !cvo.scenes is Vector.<SceneVO> )			Assert.fail("scenes collection failed");
			if ( cvo.scenes.length != 2 ) 					Assert.fail("scenes collection length incorrect");
			if ( cvo.scenes[1].uid != svo.uid ) 			Assert.fail("uid match failed");
			
			var svo2:SceneVO = cvo.getNewScene();
			if ( svo2.ordinal != 3 ) 						Assert.fail("ordinal match failed");
			if ( cvo.scenes.length != 3 ) 					Assert.fail("scenes collection length incorrect");
			if ( cvo.scenes[2].uid != svo2.uid ) 			Assert.fail("uid match failed");

		}
		
		[Test]
		public function testAddScene():void
		{
			var text1:String = "we came in?";
			var text2:String = "Isn't this where";
			var text3:String = text1 + ValueObject.DOUBLE_SPACE + text2 + ValueObject.DOUBLE_SPACE ;
			var sx1:XML = <Scene uid="234" ordinal="1"><Draft uid="456" isCurrent="true">{text1}</Draft></Scene>;
			var sx2:XML = <Scene uid="235"><Draft uid="457" isCurrent="true">{text2}</Draft></Scene>;
			var cvo:ChapterVO 	= new ChapterVO(<Chapter uid="567">{sx1}</Chapter>);
			var svo:SceneVO 	= new SceneVO(sx2);
			cvo.addScene(svo);
			if ( svo.ordinal != 2 ) 						Assert.fail("ordinal match failed");
			if ( cvo.scenes.length != 2 ) 					Assert.fail("scenes collection length incorrect");
			if ( cvo.scenes[1].uid != svo.uid ) 			Assert.fail("uid match failed");
			if ( cvo.getText() != text3 ) 					Assert.fail("getText() match failed");
		}
		
		[Test]
		public function testGetText():void
		{
			var text1:String = "we came in?";
			var text2:String = "Isn't this where";
			var text3:String = text1 + ValueObject.DOUBLE_SPACE + text2 + ValueObject.DOUBLE_SPACE ;
			var sx1:XML = <Scene uid="234"><Draft uid="456" isCurrent="true">{text1}</Draft></Scene>;
			var sx2:XML = <Scene uid="235"><Draft uid="457" isCurrent="true">{text2}</Draft></Scene>;
			var xml:XML = <Chapter uid="123">{sx1}{sx2}</Chapter>;
			var cvo:ChapterVO 	= new ChapterVO(xml);
			if (cvo.getText() != text3) Assert.fail("getText() match failed");
		}
		
		[Test]
		public function testGet_scenes():void
		{
			var text1:String = "we came in?";
			var text2:String = "Isn't this where";
			var text3:String = text1 + ValueObject.DOUBLE_SPACE + text2 + ValueObject.DOUBLE_SPACE ;
			var s1uid:String = "xxx";
			var s2uid:String = "yyy";
			var sx1:XML = <Scene uid={s1uid}><Draft uid="456" isCurrent="true">{text1}</Draft></Scene>;
			var sx2:XML = <Scene uid={s2uid}><Draft uid="457" isCurrent="true">{text2}</Draft></Scene>;
			var xml:XML = <Chapter uid="123">{sx1}{sx2}</Chapter>;
			var cvo:ChapterVO 	= new ChapterVO(xml);
			if (! cvo.scenes is Vector.<SceneVO> ) 	Assert.fail("scenes collection getter failed");
			if ( cvo.scenes.length != 2 ) 			Assert.fail("scenes collection length incorrect");
			if ( cvo.scenes[0].uid != s1uid )		Assert.fail("scene 1 uid match incorrect");
			if ( cvo.scenes[1].uid != s2uid )		Assert.fail("scene 2 uid match incorrect");
		}
	}
}