package com.futurescale.sa.model.vo.test
{
	import com.futurescale.sa.model.vo.DraftVO;
	import com.futurescale.sa.model.vo.SceneVO;
	
	import flexunit.framework.Assert;
	
	public class SceneVOTest
	{		
		[Test]
		public function testSceneVOWithoutXML():void
		{
			var vo:SceneVO = new SceneVO();
			if ( ! vo is SceneVO ) 							Assert.fail("construction failed");
			if ( ! vo.xml is XML )  						Assert.fail("default xml not provided");
			if ( vo.xml.localName() != SceneVO.ELEMENT )	Assert.fail("improper xml default");
		}
		
		[Test]
		public function testSceneVOWithXML():void
		{
			var text:String = "This is the text";
			var sceneUid:String = "Scene-33-55-ss";
			var draftUid:String = "Draft-xx-ww-22"
			var xml:XML = <Scene uid={sceneUid}><Draft uid={draftUid} isCurrent="true">{text}</Draft></Scene>;
			var vo:SceneVO = new SceneVO(xml);
			if ( ! vo is SceneVO ) 							Assert.fail("construction failed");
			if ( ! vo.xml is XML )  						Assert.fail("default xml not provided");
			if ( vo.uid != sceneUid )  						Assert.fail("scene uid match failed");
			if ( ! vo.drafts is Vector.<DraftVO> )			Assert.fail("drafts vector not returned");
			if ( vo.drafts.length != 1 )					Assert.fail("drafts vector incorrect length");
			if ( vo.drafts[0].uid != draftUid )				Assert.fail("draft uid match failed");
		}
		
		[Test]
		public function testAddDraft():void
		{
			var text:String = "This is the text";
			var text2:String = "Further to fly...";
			var sceneUid:String = "Scene-33-55-ss";
			var draftUid:String = "Draft-xx-ww-22"
			var draft2Uid:String = "Draft-xx-ss-34"
			var xml:XML = <Scene uid={sceneUid}><Draft uid={draftUid} isCurrent="true">{text}</Draft></Scene>;
			var dvo:DraftVO = new DraftVO(<Draft uid={draft2Uid}>{text2}</Draft>);
			var vo:SceneVO = new SceneVO(xml);
			vo.addDraft(dvo);
			if ( vo.drafts.length != 2 )					Assert.fail("drafts vector incorrect length");
			if ( vo.drafts[1].uid != draft2Uid )			Assert.fail("draft uid match failed");
		}
		
		[Test]
		public function testGetCurrentDraft():void
		{
			var text1:String = "This is the text";
			var text2:String = "Further to fly...";
			var text3:String = "Once upon a time";
			var draft1Uid:String = "Draft-yy-ww-22"
			var draft2Uid:String = "Draft-xx-ss-34"
			var draft3Uid:String = "Draft-dd-vv-12"
			var dvo1:DraftVO = new DraftVO(<Draft uid={draft1Uid} isCurrent="false">{text1}</Draft>);
			var dvo2:DraftVO = new DraftVO(<Draft uid={draft2Uid} isCurrent="true">{text2}</Draft>);
			var dvo3:DraftVO = new DraftVO(<Draft uid={draft3Uid} isCurrent="false">{text3}</Draft>);
			var vo:SceneVO = new SceneVO();
			vo.addDraft(dvo1);
			vo.addDraft(dvo2);
			vo.addDraft(dvo3);
			var currentDraft:DraftVO = vo.currentDraft;
			if ( vo.drafts.length != 4 )				Assert.fail("drafts vector incorrect length");
			if ( ! currentDraft is DraftVO )			Assert.fail("no draft not returned");
			if ( currentDraft.uid != draft3Uid )		Assert.fail("draft uid match failed");
		}
		
		[Test]
		public function testGetText():void
		{
			var text1:String = "This is the text";
			var text2:String = "Further to fly...";
			var text3:String = "Once upon a time";
			var draft1Uid:String = "Draft-yy-ww-22"
			var draft2Uid:String = "Draft-xx-ss-34"
			var draft3Uid:String = "Draft-dd-vv-12"
			var dvo1:DraftVO = new DraftVO(<Draft uid={draft1Uid} isCurrent="false">{text1}</Draft>);
			var dvo2:DraftVO = new DraftVO(<Draft uid={draft2Uid} isCurrent="true">{text2}</Draft>);
			var dvo3:DraftVO = new DraftVO(<Draft uid={draft3Uid} isCurrent="false">{text3}</Draft>);
			var vo:SceneVO = new SceneVO();
			if ( vo.getText() != "" ) 				Assert.fail("getText() match failed");

			vo.addDraft(dvo1);
			vo.addDraft(dvo2);
			vo.addDraft(dvo3);
			if ( vo.getText() != dvo3.text )		Assert.fail("getText() match failed");

			vo.currentDraft = dvo2;
			if ( vo.getText() != dvo2.text )		Assert.fail("getText() match failed");
		}
		[Test]
		public function testGetNewDraft():void
		{
			var text1:String = "This is the text";
			var draft1Uid:String = "Draft-yy-ww-22"
			var dvo1:DraftVO = new DraftVO(<Draft uid={draft1Uid} ordinal="5" isCurrent="true">{text1}</Draft>);
			var vo:SceneVO = new SceneVO();
			vo.addDraft(dvo1);
			var newDraft:DraftVO = vo.getNewDraft();
			if ( vo.drafts.length != 3 )			Assert.fail("drafts collection incorrect length");
			if ( ! newDraft is DraftVO )			Assert.fail("no draft not returned");
			if ( newDraft.ordinal != 3 )			Assert.fail("new draft ordinal failed");
			if ( newDraft.text != "" )				Assert.fail("new draft text match failed");
			if ( newDraft.isCurrent != true )  		Assert.fail("new draft isCurrent match failed");
			if ( dvo1.isCurrent == true )  			Assert.fail("first draft isCurrent match failed");
		}
		
		[Test]
		public function testGetRevisionDraft():void
		{
			var text1:String = "This is the text";
			var draft1Uid:String = "Draft-yy-ww-22"
			var dvo1:DraftVO = new DraftVO(<Draft uid={draft1Uid} ordinal="1" isCurrent="true">{text1}</Draft>);
			var vo:SceneVO = new SceneVO();
			vo.addDraft(dvo1);
			var revisionDraft:DraftVO = vo.getRevisionDraft(dvo1);
			if ( vo.drafts.length != 3 )			Assert.fail("drafts collection incorrect length");
			if ( ! revisionDraft is DraftVO )		Assert.fail("no draft not returned");
			if ( revisionDraft.uid == draft1Uid )	Assert.fail("revision draft uid should not match");
			if ( revisionDraft.ordinal != 3 )		Assert.fail("revision draft ordinal failed");
			if ( revisionDraft.text != dvo1.text )	Assert.fail("revision draft text match failed");
			if ( revisionDraft.isCurrent != true )  Assert.fail("revision draft isCurrent match failed");
			if ( dvo1.isCurrent == true )  			Assert.fail("first draft isCurrent match failed");

			if ( vo.getText() != dvo1.text ) Assert.fail("getText() match failed");
			var revisedText:String = "This is the new text";
			revisionDraft.text = revisedText;
			if ( vo.getText() != revisionDraft.text ) Assert.fail("getText() match failed");
		}
	}
}