package com.futurescale.sa.model.vo.test
{
	import com.futurescale.sa.model.enum.StoryTypeEnum;
	import com.futurescale.sa.model.vo.ChapterVO;
	import com.futurescale.sa.model.vo.PartVO;
	import com.futurescale.sa.model.vo.SceneVO;
	import com.futurescale.sa.model.vo.SeriesVO;
	import com.futurescale.sa.model.vo.StoryVO;
	import com.futurescale.sa.model.vo.ValueObject;
	
	import flexunit.framework.Assert;
	
	public class StoryVOTest
	{		
		
		[Test]
		public function testStoryVOWithoutXML():void
		{
			var vo:StoryVO = new StoryVO();
			if ( ! vo is StoryVO ) 							Assert.fail("construction failed");
			if ( ! vo.xml is XML )  						Assert.fail("default xml not provided");
			if ( vo.xml.localName() != StoryVO.ELEMENT )	Assert.fail("improper xml default");
			if ( vo.cast != null )							Assert.fail("non null cast at creation");
			if ( vo.milieu != null )						Assert.fail("non null milieu at creation");
			if ( vo.isEpisode )								Assert.fail("isEpisode match failed");
		}
		
		[Test]
		public function testStoryVOWithXML():void
		{
			var text:String 	  = "This is the text";
			var storyUid:String   = "Story-fghsdf-23";
			var chapterUid:String = "Chapter-hj-tt-35";
			var sceneUid:String   = "Scene-33-55-ss";
			var draftUid:String   = "Draft-xx-ww-22"
			var xml:XML = <Story uid={storyUid} type={StoryTypeEnum.NORMAL.ordinal}><Chapter uid={chapterUid}><Scene uid={sceneUid}><Draft uid={draftUid} isCurrent="true">{text}</Draft></Scene></Chapter></Story>;
			var vo:StoryVO = new StoryVO(xml);
			if ( ! vo is StoryVO ) 						Assert.fail("construction failed");
			if ( ! vo.xml is XML )  					Assert.fail("default xml not provided");
			if ( vo.uid != storyUid )  					Assert.fail("story uid match failed");
			if ( vo.type != StoryTypeEnum.NORMAL )		Assert.fail("story type match failed");
			if ( ! vo.chapters is Vector.<ChapterVO> )	Assert.fail("chapters vector not returned");
			if ( vo.chapters.length != 1 )				Assert.fail("chapters vector incorrect length");
			if ( vo.chapters[0].uid != chapterUid )		Assert.fail("chapterUid uid match failed");
			if ( vo.isEpisode )							Assert.fail("isEpisode match failed");
	}
		
		[Test]
		public function testAddScene():void
		{
			var vo:StoryVO = new StoryVO();
			var scene:SceneVO = new SceneVO();
			vo.addScene( scene );
			if ( vo.type != StoryTypeEnum.SIMPLE )			Assert.fail("story type match failed");
			if ( ! vo.scenes is Vector.<SceneVO> )			Assert.fail("scenes vector not returned");
			if ( vo.scenes.length != 1 )					Assert.fail("scenes vector incorrect length");
			if ( vo.scenes[0].uid != scene.uid )			Assert.fail("scene uid match failed");
		}
		
		[Test]
		public function testAddChapter():void
		{
			var vo:StoryVO = new StoryVO();
			var chapter:ChapterVO = new ChapterVO();
			vo.addChapter( chapter );
			if ( vo.type != StoryTypeEnum.NORMAL )			Assert.fail("story type match failed");
			if ( ! vo.chapters is Vector.<ChapterVO> )		Assert.fail("chapters vector not returned");
			if ( vo.chapters.length != 1 )					Assert.fail("chapters vector incorrect length");
			if ( vo.chapters[0].uid != chapter.uid )		Assert.fail("chapter uid match failed");
		}
		
		[Test]
		public function testAddPart():void
		{
			var vo:StoryVO = new StoryVO();
			var part:PartVO = new PartVO();
			vo.addPart( part );
			if ( vo.type != StoryTypeEnum.COMPLEX )			Assert.fail("story type match failed");
			if ( ! vo.parts is Vector.<PartVO> )			Assert.fail("parts vector not returned");
			if ( vo.parts.length != 1 )						Assert.fail("parts vector incorrect length");
			if ( vo.parts[0].uid != part.uid )				Assert.fail("part uid match failed");
		}
		
		[Test]
		public function testGetNewScene():void
		{
			var vo:StoryVO = new StoryVO();
			var scene1:SceneVO = vo.getNewScene();
			var scene2:SceneVO = vo.getNewScene();
			if ( vo.type != StoryTypeEnum.SIMPLE )			Assert.fail("story type match failed");
			if ( ! vo.scenes is Vector.<SceneVO> )			Assert.fail("scenes vector not returned");
			if ( vo.scenes.length != 2 )					Assert.fail("scenes vector incorrect length");
			if ( vo.scenes[0].uid != scene1.uid )			Assert.fail("scene1 uid match failed");
			if ( vo.scenes[1].uid != scene2.uid )			Assert.fail("scene2 uid match failed");
			if ( vo.scenes[0].name != "Scene 1" )			Assert.fail("scene1 name match failed");
			if ( vo.scenes[1].name != "Scene 2" )			Assert.fail("scene2 name match failed");
			
		}
		
		[Test]
		public function testGetNewChapter():void
		{
			var vo:StoryVO = new StoryVO();
			var chapter1:ChapterVO = vo.getNewChapter();
			var chapter2:ChapterVO = vo.getNewChapter();
			if ( vo.type != StoryTypeEnum.NORMAL )			Assert.fail("story type match failed");
			if ( ! vo.chapters is Vector.<ChapterVO> )		Assert.fail("chapters vector not returned");
			if ( vo.chapters.length != 2 )					Assert.fail("chapters vector incorrect length");
			if ( vo.chapters[0].uid != chapter1.uid )		Assert.fail("chapter1 uid match failed");
			if ( vo.chapters[1].uid != chapter2.uid )		Assert.fail("chapter2 uid match failed");
			if ( vo.chapters[0].name != "Chapter 1" )		Assert.fail("chapter1 name match failed");
			if ( vo.chapters[1].name != "Chapter 2" )		Assert.fail("chapter2 name match failed");
		}
		
		[Test]
		public function testGetNewPart():void
		{
			var vo:StoryVO = new StoryVO();
			var part1:PartVO = vo.getNewPart();
			var part2:PartVO = vo.getNewPart();
			if ( vo.type != StoryTypeEnum.COMPLEX )			Assert.fail("story type match failed");
			if ( ! vo.parts is Vector.<PartVO> )			Assert.fail("parts vector not returned");
			if ( vo.parts.length != 2 )						Assert.fail("parts vector incorrect length");
			if ( vo.parts[0].uid != part1.uid )				Assert.fail("part1 uid match failed");
			if ( vo.parts[1].uid != part2.uid )				Assert.fail("part2 uid match failed");
			if ( vo.parts[0].name != "Part 1" )				Assert.fail("part1 name match failed");
			if ( vo.parts[1].name != "Part 2" )				Assert.fail("part2 name match failed");
		}
		
		[Test]
		public function testSet_type():void
		{
			var vo:StoryVO = new StoryVO();
			vo.type = StoryTypeEnum.COMPLEX;
			if ( vo.type != StoryTypeEnum.COMPLEX )			Assert.fail("story type match failed");
			if ( vo.useScenes 	== true)					Assert.fail("useScenes match failed");
			if ( vo.useChapters == true)					Assert.fail("useChapters match failed");
			if ( vo.useParts	!= true)					Assert.fail("useParts match failed");
			
			vo.type = StoryTypeEnum.NORMAL;
			if ( vo.type != StoryTypeEnum.NORMAL )			Assert.fail("story type match failed");
			if ( vo.useScenes 	== true)					Assert.fail("useScenes match failed");
			if ( vo.useChapters != true)					Assert.fail("useChapters match failed");
			if ( vo.useParts	== true)					Assert.fail("useParts match failed");
			
			vo.type = StoryTypeEnum.SIMPLE;
			if ( vo.type != StoryTypeEnum.SIMPLE )			Assert.fail("story type match failed");
			if ( vo.useScenes 	!= true)					Assert.fail("useScenes match failed");
			if ( vo.useChapters == true)					Assert.fail("useChapters match failed");
			if ( vo.useParts	== true)					Assert.fail("useParts match failed");
		}
		
		[Test]
		public function testSet_useChapters():void
		{
			var vo:StoryVO = new StoryVO();
			vo.useChapters = true;
			if ( vo.type != StoryTypeEnum.NORMAL )			Assert.fail("story type match failed");
			if ( vo.useScenes 	== true)					Assert.fail("useScenes match failed");
			if ( vo.useChapters != true)					Assert.fail("useChapters match failed");
			if ( vo.useParts	== true)					Assert.fail("useParts match failed");
		}
		
		[Test]
		public function testSet_useParts():void
		{
			var vo:StoryVO = new StoryVO();
			vo.useParts = true;
			if ( vo.type != StoryTypeEnum.COMPLEX )			Assert.fail("story type match failed");
			if ( vo.useScenes 	== true)					Assert.fail("useScenes match failed");
			if ( vo.useChapters == true)					Assert.fail("useChapters match failed");
			if ( vo.useParts	!= true)					Assert.fail("useParts match failed");
		}
		
		[Test]
		public function testSet_useScenes():void
		{
			var vo:StoryVO = new StoryVO();
			vo.useScenes = true;
			if ( vo.type != StoryTypeEnum.SIMPLE )			Assert.fail("story type match failed");
			if ( vo.useScenes 	!= true)					Assert.fail("useScenes match failed");
			if ( vo.useChapters == true)					Assert.fail("useChapters match failed");
			if ( vo.useParts	== true)					Assert.fail("useParts match failed");
		}
		
		[Test]
		public function testSet_Series():void
		{
			var vo:StoryVO = new StoryVO();
			var series:SeriesVO = new SeriesVO();
			vo.series = series;
			if ( ! vo.series )								Assert.fail("series not set");
			if ( vo.series.uid != series.uid )				Assert.fail("series  match failed");
			if ( ! vo.isEpisode  )							Assert.fail("isEpisode match failed");
		}
		
		[Test]
		public function testGetText():void
		{
			var text1:String = "we came in?";
			var text2:String = "Isn't this where";
			var text3:String = text1 + ValueObject.DOUBLE_SPACE + text2 + ValueObject.DOUBLE_SPACE ;
			var sx1:XML = <Scene uid="234"><Draft uid="456" isCurrent="true">{text1}</Draft></Scene>;
			var sx2:XML = <Scene uid="235"><Draft uid="457" isCurrent="true">{text2}</Draft></Scene>;
			var xml:XML = <Chapter uid="123">{sx1}{sx2}</Chapter>;
			var cvo:ChapterVO 	= new ChapterVO(xml);
			var vo:StoryVO = new StoryVO();
			vo.addChapter(cvo);
			var text4:String = vo.getText(false);
			if (text4 != text3) Assert.fail("getText() match failed");
		}
	}
}